@@ -29,7 +29,7 @@ use constant SOUTH_REGIME_END => DateTime->new(
     day => 27,
     time_zone => 'Asia/Tokyo'
 );
-our $VERSION = '0.08002';
+our $VERSION = '0.08003';
 our @EXPORT_OK = qw(SOUTH_REGIME NORTH_REGIME);
 
 __PACKAGE__->mk_accessors($_) for qw(id name start end);
@@ -214,14 +214,14 @@ sub load_from_file
         if ( $opts->{is_south_regime} ) {
             push @SOUTH_REGIME_ERAS, __PACKAGE__->new(
                 id => $this_era->[$ID],
-                name => Encode::decode_utf8($this_era->[$NAME]),
+                name => $this_era->[$NAME],
                 start => $start_date, 
                 end => $end_date, 
             );
         } else {
             __PACKAGE__->register_era(
                 id    => $this_era->[$ID],
-                name  => Encode::decode_utf8($this_era->[$NAME]),
+                name  => $this_era->[$NAME],
                 start => $start_date,
                 end   => $end_date
             );
@@ -243,6 +243,8 @@ __DATA__
 
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 DateTime::Calendar::Japanese::Era - DateTime Extension for Japanese Eras
@@ -257,7 +259,7 @@ DateTime::Calendar::Japanese::Era - DateTime Extension for Japanese Eras
     id => HEISEI_ERA
   );
   my $era = DateTime::Calendar::Japanese::Era->lookup_by_name(
-    name => "ʿ"
+    name => "平成"
   );
 
   my $era = DateTime::Calendar::Japanese::Era->new(
